# Annotation

Annotation commands are used to create, position, and modify viewport annotations.

## Create annotations

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Arrow
```

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Text
```

```{eval-rst}
.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.XYData

```

## Classes

### Annotation

```{eval-rst}
.. autoclass:: abaqus.Annotation.Annotation.Annotation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnnotationsToPlotArray

```{eval-rst}
.. autoclass:: abaqus.Annotation.AnnotationsToPlotArray.AnnotationsToPlotArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnnotationViewport

```{eval-rst}
.. autoclass:: abaqus.Annotation.AnnotationViewport.AnnotationViewport
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Arrow

```{eval-rst}
.. autoclass:: abaqus.Annotation.Arrow.Arrow
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Text

```{eval-rst}
.. autoclass:: abaqus.Annotation.Text.Text
    :members:
    :special-members: __init__
```
